@@ -78,11 +78,11 @@ c
       if(rigc .eq. 0) then
          write(*,*) ' No rigidity cut is assumed'
          write(*,*)
-     "   ' primary  Int(dI/dE)  sum(cumlative);'
+     *   ' primary  Int(dI/dE)  sum(cumlative);'
       else
          write(*,*) ' Rigidity cut is  applied'
          write(*,*)
-     "   ' primary  Int(dI/dE*RigCut)  sum(cumlative);'
+     *   ' primary  Int(dI/dE*RigCut)  sum(cumlative);'
       endif
       sum = 0.
       do i = 1, Prim.no_of_comps
