@@ -86,7 +86,7 @@ c	(->	--------------------------------------------
                               !     enough for normal cases where particles are inside the atmosphere.(default) \newline
                               !     In every case below, if the particle height is $<$ 30km  
                               !    (= cheight in ccomPathEnd.f), the same method as 0 is used. \newline
-                              ! 1$\rightarrow$ Use the Euler method.  Time needed is 20% more than the 0 case.
+                              ! 1$\rightarrow$ Use the Euler method.  Time needed is 20\% more than the 0 case.
                               !      As B, use the value at L/2 point obtained by using the current direction. \newline
                               ! 2$\rightarrow$ mixture of 1 and Runge-Kutta-Gill method. If gradient of B is large, RKG is
                               !      employed. This needs $\sim$4 times more cpu time than case of 1 when making a
