@@ -60,9 +60,7 @@ c        reset parameters
       if(BorderHeightH .eq. 0.0) then
          BorderHeightH = HeightOfInj + 1.0d0    ! from v6.10
       endif
-c////////////
-      write(0, *) ' BorderHeightH=',BorderHeightH 
-c/////////////
+
       EventsInTheRun = 0      ! moved from ciniTracking0. 2001.09/30
 
       if(DestEventNo(2) .eq. 0) then
