@@ -28,10 +28,10 @@ c             den = cthick2den(TrackBefMove.pos.depth)
        call csetIntInf(t*X0, .false., 'brems')
        if(Knockon) then
           if(TrackBefMove.p.charge .eq. -1) then
-             call cmollerPath(ee,  RecoilKineMinE, t)
+             call cmollerPath(ee,  RecoilKineMinE, prob, t)
              call csetIntInf(t*X0, .false., 'mscat')
           else
-             call cbhabhaPath(ee,  RecoilKineMinE, t)
+             call cbhabhaPath(ee,  RecoilKineMinE, prob, t)
              call csetIntInf(t*X0, .false., 'bscat')
           endif
        endif
@@ -40,7 +40,7 @@ c             den = cthick2den(TrackBefMove.pos.depth)
           if(ee - TrackBefMove.p.mass .lt. 100.e-6) then
              t = 0.
           else
-             call canihiPath(ee, t)
+             call canihiPath(ee, prob, t)
           endif
           call csetIntInf(t*X0, .false., 'anihi')
        endif
